@@ -10,13 +10,18 @@ class ClientModel(ABC):
         match_case is an optional [str] that is used to either exact match or case insensitive match the keys in the dict
             default: insensitive match
             example: "exact" or "insensitive"
+        ignored_list is an optional [list] of strings that are used to ignore the keys in the dict
+            example: ['querytime', 'querytime_ms', 'querytime-ms']
     '''
-    def __init__(self, _dict=None, author=None, plugin_version=1, heartbeat_required="true", date_created=None, match_list=None, match_case="insensitive"):
+    def __init__(self, _dict=None, author=None, plugin_version=1, heartbeat_required="true",
+    date_created=None, match_list=None, match_case="insensitive", ignored_list=None):
         self.dict = {}
         if not author:
             self.author = "TechStyleOS"
         else:
             self.author = author
+        if not ignored_list:
+            self.ignored_list = []
         self.__setitem__('author', self.author)
         self.plugin_version = plugin_version
         self.__setitem__('plugin_version', self.plugin_version)
@@ -37,6 +42,8 @@ class ClientModel(ABC):
                             self.__setitem__(key, _dict[key])
         elif _dict:
             self.dict.update(_dict)
+        for key in ignored_list:
+            self.__delitem__(key)
         self.validate()
 
     def __getitem__(self, key):
@@ -127,3 +134,10 @@ class ClientModel(ABC):
     def get_unit(self, key):
         ''' get the unit for the metric '''
         del self.dict['units'][key]
+
+    def check_ignored_list(self, key):
+        ''' check if the key is in the ignored list '''
+        if key in self.ignored_list:
+            return True
+        else:
+            return False
