@@ -73,9 +73,9 @@ if __name__ == "__main__":
             cache[key] = value
     # # validate data before saving to cache
     # ww = connector.validatePluginData(cache)
-    # breakpoint() 
+    
     # save cache to file as this_plugin_name 
-    cache_file_name = "/tmp/" + this_plugin_name + ".cache"
+    cache_file_name = "/tmp/" + this_plugin_name.replace("/", "") + ".cache"
     open(cache_file_name, 'w', encoding='utf8').write(
         json.dumps(cache, indent=4)
     )
@@ -96,7 +96,7 @@ if __name__ == "__main__":
         call(f"touch {file_destination}", shell=True)
         open(file_destination, 'w', encoding="utf8").write(f"""#!/usr/bin/env python3
 '''
-   this file is generated by Jenkins on {special_strftime()}
+   this file is generated using Jenkins, and it is a cron-task
 '''
 from site24x7_plugin_helper.connector.cache_client import CacheClient
 
@@ -105,6 +105,7 @@ CLIENT = CacheClient(
     author="Renas Mirkan Kilic",
     plugin_version="1",
     date_created="{special_strftime()}"
+    ignored_list=["database", "query", "this_plugin_name"]
 )
 
 def metric_collector():
